@@ -62,7 +62,9 @@ typedef enum
     SRC_PRESENTATION_STATE_MINIMIZED,
     SRC_PRESENTATION_CHILDREN_COUNT,
     SRC_PRESENTATION_VALUE_CRT,
-    SRC_PRESENTATION_HEADER,
+    SRC_PRESENTATION_COLUMN_HEADER,
+    SRC_PRESENTATION_ROW_HEADER,
+    SRC_PRESENTATION_CELL,
     SRC_PRESENTATION_NONE
 }SRCPresentationItemType;
 
@@ -210,7 +212,9 @@ src_presentation_get_item_type (const gchar *item)
 	    {SRC_PRESENTATION_STATE_MINIMIZED,	"state:minimized"},
 	    {SRC_PRESENTATION_CHILDREN_COUNT,	"childcount"},
 	    {SRC_PRESENTATION_VALUE_CRT,	"value:crt"},
-	    {SRC_PRESENTATION_HEADER,	        "header"}
+	    {SRC_PRESENTATION_COLUMN_HEADER,	"column_header"},
+	    {SRC_PRESENTATION_ROW_HEADER,       "row_header"},
+	    {SRC_PRESENTATION_CELL,             "cell"}
 	};
     gint i;
 
@@ -1116,10 +1120,10 @@ src_presentation_get_info_from_sro (SRObject *obj,
 		}
 	    }
 	    break;
-	case SRC_PRESENTATION_HEADER:
+	case SRC_PRESENTATION_COLUMN_HEADER:
 	    {
 		gchar *tmp;
-		rv = sro_get_header (obj, &tmp, SR_INDEX_CONTAINER);
+		rv = sro_get_column_header (obj, &tmp, SR_INDEX_CONTAINER);
 		if (rv)
 		{
 		    *((gchar **)info) = g_strdup (tmp);
@@ -1127,6 +1131,28 @@ src_presentation_get_info_from_sro (SRObject *obj,
 		}
 	    }
 	    break;
+	case SRC_PRESENTATION_ROW_HEADER:
+	    {
+		gchar *tmp;
+		rv = sro_get_row_header (obj, &tmp, SR_INDEX_CONTAINER);
+		if (rv)
+		{
+		    *((gchar **)info) = g_strdup (tmp);
+		    SR_freeString (tmp);
+		}
+	    }
+	    break;    
+	case SRC_PRESENTATION_CELL:
+	    {
+		gchar *tmp;
+		rv = sro_get_cell (obj, &tmp, SR_INDEX_CONTAINER);
+		if (rv)
+		{
+		    *((gchar **)info) = g_strdup (tmp);
+		    SR_freeString (tmp);
+		}
+	    }    
+	    break;
 	default:
 	    fprintf (stderr, "\n%d", info_type);/* removable */
 	    sru_assert_not_reached ();	
